netapp_ontap.models.ems_event_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ems_event_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class EmsEventResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the EmsEventResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `index: Size GET`

    Index of the event. Returned by default.

    Example: 1

  `links: EmsEventLinks GET`

    The links field of the ems_event_response_records.

  `log_message: str GET PATCH`

    A formatted text string populated with parameter details. Returned by default.

  `message: EmsEventMessage1 GET`

    The message field of the ems_event_response_records.

  `node: Node GET`

    The node field of the ems_event_response_records.

  `parameters: List[EmsEventParameters] GET`

    A list of parameters provided with the EMS event.

  `source: str GET`

    Source

  `time: ImpreciseDateTime GET`

    Timestamp of the event. Returned by default.